@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2013-2015 Laurent Montel <montel@kde.org>
+    Copyright (c) 2013-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -97,8 +97,7 @@ QHash<Akonadi::Collection, bool> NewMailNotifierCollectionProxyModel::notificati
 }
 
 NewMailNotifierSelectCollectionWidget::NewMailNotifierSelectCollectionWidget(QWidget *parent)
-    : QWidget(parent),
-      mNeedUpdate(false)
+    : QWidget(parent)
 {
     Akonadi::AttributeFactory::registerAttribute<Akonadi::NewMailNotifierAttribute>();
     QVBoxLayout *vbox = new QVBoxLayout(this);
@@ -138,7 +137,7 @@ NewMailNotifierSelectCollectionWidget::NewMailNotifierSelectCollectionWidget(QWi
 
     vbox->addWidget(searchLine);
 
-    mFolderView = new QTreeView;
+    mFolderView = new QTreeView(this);
     mFolderView->setEditTriggers(QAbstractItemView::NoEditTriggers);
     mFolderView->setAlternatingRowColors(true);
     vbox->addWidget(mFolderView);
@@ -201,13 +200,13 @@ void NewMailNotifierSelectCollectionWidget::updateCollectionsRecursive()
         i.next();
         Akonadi::Collection collection = i.key();
         Akonadi::NewMailNotifierAttribute *attr = collection.attribute<Akonadi::NewMailNotifierAttribute>();
-        Akonadi::CollectionModifyJob *modifyJob = Q_NULLPTR;
+        Akonadi::CollectionModifyJob *modifyJob = nullptr;
         const bool selected = i.value();
         if (selected && attr && attr->ignoreNewMail()) {
             collection.removeAttribute<Akonadi::NewMailNotifierAttribute>();
             modifyJob = new Akonadi::CollectionModifyJob(collection);
             modifyJob->setProperty("AttributeAdded", true);
-        } else if (!selected && (!attr || !attr->ignoreNewMail())) {
+        } else if (!selected && (!attr || (attr && !attr->ignoreNewMail()))) {
             attr = collection.attribute<Akonadi::NewMailNotifierAttribute>(Akonadi::Collection::AddIfMissing);
             attr->setIgnoreNewMail(true);
             modifyJob = new Akonadi::CollectionModifyJob(collection);
