@@ -18,7 +18,7 @@
 
 #include "setupwizard.h"
 
-#include "davcollectionsmultifetchjob.h"
+#include <KDAV/DavCollectionsMultiFetchJob>
 
 #include <qicon.h>
 #include <KLocalizedString>
@@ -186,16 +186,16 @@ SetupWizard::Url::List SetupWizard::urls() const
         return urls;
     }
 
-    QStringList supportedProtocols = service->property(QStringLiteral("X-DavGroupware-SupportedProtocols")).toStringList();
-    foreach (const QString &protocol, supportedProtocols) {
+    const QStringList supportedProtocols = service->property(QStringLiteral("X-DavGroupware-SupportedProtocols")).toStringList();
+    for (const QString &protocol : supportedProtocols) {
         Url url;
 
         if (protocol == QLatin1String("CalDav")) {
-            url.protocol = DavUtils::CalDav;
+            url.protocol =KDAV::CalDav;
         } else if (protocol == QLatin1String("CardDav")) {
-            url.protocol = DavUtils::CardDav;
+            url.protocol = KDAV::CardDav;
         } else if (protocol == QLatin1String("GroupDav")) {
-            url.protocol = DavUtils::GroupDav;
+            url.protocol = KDAV::GroupDav;
         } else {
             return urls;
         }
@@ -318,12 +318,11 @@ ServerTypePage::ServerTypePage(QWidget *parent)
 
     mProvidersCombo = new QComboBox(this);
     mProvidersCombo->setSizeAdjustPolicy(QComboBox::AdjustToContents);
-    KService::List providers;
     KServiceTypeTrader *trader = KServiceTypeTrader::self();
-    providers = trader->query(QStringLiteral("DavGroupwareProvider"));
+    const KService::List providers = trader->query(QStringLiteral("DavGroupwareProvider"));
     QList< QPair<QString, QString> > offers;
     offers.reserve(providers.count());
-    foreach (const KService::Ptr &provider, providers) {
+    for (const KService::Ptr &provider : providers) {
         offers.append(QPair<QString, QString>(provider->name(), provider->entryPath()));
     }
     std::sort(offers.begin(), offers.end(), compareServiceOffers);
@@ -383,7 +382,7 @@ bool ServerTypePage::validatePage()
  */
 
 ConnectionPage::ConnectionPage(QWidget *parent)
-    : QWizardPage(parent), mPreviewLayout(Q_NULLPTR), mCalDavUrlPreview(Q_NULLPTR), mCardDavUrlPreview(Q_NULLPTR), mGroupDavUrlPreview(Q_NULLPTR)
+    : QWizardPage(parent), mPreviewLayout(nullptr), mCalDavUrlPreview(nullptr), mCardDavUrlPreview(nullptr), mGroupDavUrlPreview(nullptr)
 {
     setTitle(i18n("Connection"));
     setSubTitle(i18n("Enter the connection information for the groupware server"));
@@ -450,19 +449,19 @@ void ConnectionPage::cleanupPage()
     if (mCalDavUrlPreview) {
         delete mCalDavUrlLabel;
         delete mCalDavUrlPreview;
-        mCalDavUrlPreview = Q_NULLPTR;
+        mCalDavUrlPreview = nullptr;
     }
 
     if (mCardDavUrlPreview) {
         delete mCardDavUrlLabel;
         delete mCardDavUrlPreview;
-        mCardDavUrlPreview = Q_NULLPTR;
+        mCardDavUrlPreview = nullptr;
     }
 
     if (mGroupDavUrlPreview) {
         delete mGroupDavUrlLabel;
         delete mGroupDavUrlPreview;
-        mGroupDavUrlPreview = Q_NULLPTR;
+        mGroupDavUrlPreview = nullptr;
     }
 
     QWizardPage::cleanupPage();
@@ -519,12 +518,12 @@ void CheckPage::checkConnection()
 {
     mStatusLabel->clear();
 
-    DavUtils::DavUrl::List davUrls;
+    KDAV::DavUrl::List davUrls;
 
-    // convert list of SetupWizard::Url to list of DavUtils::DavUrl
+    // convert list of SetupWizard::Url to list of KDAV::DavUrl
     const SetupWizard::Url::List urls = static_cast<SetupWizard *>(wizard())->urls();
-    foreach (const SetupWizard::Url &url, urls) {
-        DavUtils::DavUrl davUrl;
+    for (const SetupWizard::Url &url : urls) {
+        KDAV::DavUrl davUrl;
         davUrl.setProtocol(url.protocol);
 
         QUrl serverUrl(url.url);
@@ -536,8 +535,8 @@ void CheckPage::checkConnection()
     }
 
     // start the dav collections fetch job to test connectivity
-    DavCollectionsMultiFetchJob *job = new DavCollectionsMultiFetchJob(davUrls, this);
-    connect(job, &DavCollectionsMultiFetchJob::result, this, &CheckPage::onFetchDone);
+    KDAV::DavCollectionsMultiFetchJob *job = new KDAV::DavCollectionsMultiFetchJob(davUrls, this);
+    connect(job, & KDAV::DavCollectionsMultiFetchJob::result, this, &CheckPage::onFetchDone);
     job->start();
 }
 
