@@ -40,6 +40,9 @@ public:
 
     ~ContactsResource();
 
+protected:
+    using ResourceBase::retrieveItems; // Suppress -Woverload-virtual
+
 protected Q_SLOTS:
     void retrieveCollections() Q_DECL_OVERRIDE;
     void retrieveItems(const Akonadi::Collection &collection) Q_DECL_OVERRIDE;
