@@ -49,14 +49,14 @@
 #include <kimap/searchjob.h>
 #include <kimap/statusjob.h>
 
-RetrieveItemsTask::RetrieveItemsTask(ResourceStateInterface::Ptr resource, QObject *parent)
+RetrieveItemsTask::RetrieveItemsTask(const ResourceStateInterface::Ptr &resource, QObject *parent)
     : ResourceTask(CancelIfNoSession, resource, parent),
-      m_session(Q_NULLPTR),
+      m_session(nullptr),
       m_fetchedMissingBodies(-1),
       m_fetchMissingBodies(false),
       m_incremental(true),
       m_localHighestModSeq(-1),
-      m_batchFetcher(Q_NULLPTR),
+      m_batchFetcher(nullptr),
       m_uidBasedFetch(true),
       m_flagsChanged(false),
       m_messageCount(-1),
@@ -135,7 +135,8 @@ void RetrieveItemsTask::fetchItemsWithoutBodiesDone(KJob *job)
     } else {
         int i = 0;
         Akonadi::ItemFetchJob *fetch = static_cast<Akonadi::ItemFetchJob *>(job);
-        Q_FOREACH (const Akonadi::Item &item, fetch->items())  {
+        const Akonadi::Item::List lstItems = fetch->items();
+        for (const Akonadi::Item &item : lstItems)  {
             if (!item.cachedPayloadParts().contains(Akonadi::MessagePart::Body)) {
                 qCWarning(IMAPRESOURCE_LOG) << "Item " << item.id() << " is missing the payload! Cached payloads: " << item.cachedPayloadParts();
                 uids.append(item.remoteId().toInt());
@@ -273,8 +274,8 @@ void RetrieveItemsTask::onStatusDone(KJob *job)
     }
 
     KIMAP::StatusJob *status = qobject_cast<KIMAP::StatusJob *>(job);
-    QList<QPair<QByteArray, qint64>> results = status->status();
-    Q_FOREACH (const auto &val, results) {
+    const QList<QPair<QByteArray, qint64>> results = status->status();
+    for (const auto &val : results) {
         if (val.first == "UIDNEXT") {
             m_nextUid = val.second;
             break;
@@ -558,7 +559,7 @@ void RetrieveItemsTask::onItemsRetrieved(const Akonadi::Item::List &addedItems)
 
 void RetrieveItemsTask::onRetrievalDone(KJob *job)
 {
-    m_batchFetcher = Q_NULLPTR;
+    m_batchFetcher = nullptr;
     if (job->error()) {
         qCWarning(IMAPRESOURCE_LOG) << job->errorString();
         cancelTask(job->errorString());
@@ -616,7 +617,7 @@ void RetrieveItemsTask::listFlagsForImapSet(const KIMAP::ImapSet &set)
 
 void RetrieveItemsTask::onFlagsFetchDone(KJob *job)
 {
-    m_batchFetcher = Q_NULLPTR;
+    m_batchFetcher = nullptr;
     if (job->error()) {
         qCWarning(IMAPRESOURCE_LOG) << job->errorString();
         cancelTask(job->errorString());
