@@ -30,8 +30,8 @@
 #include <kimap/selectjob.h>
 #include <kimap/session.h>
 
-RetrieveItemTask::RetrieveItemTask(ResourceStateInterface::Ptr resource, QObject *parent)
-    : ResourceTask(CancelIfNoSession, resource, parent), m_session(Q_NULLPTR), m_uid(0), m_messageReceived(false)
+RetrieveItemTask::RetrieveItemTask(const ResourceStateInterface::Ptr &resource, QObject *parent)
+    : ResourceTask(CancelIfNoSession, resource, parent), m_session(nullptr), m_uid(0), m_messageReceived(false)
 {
 
 }
@@ -106,7 +106,7 @@ void RetrieveItemTask::onMessagesReceived(const QString &mailBox,
     Q_UNUSED(mailBox);
 
     KIMAP::FetchJob *fetch = qobject_cast<KIMAP::FetchJob *>(sender());
-    Q_ASSERT(fetch != 0);
+    Q_ASSERT(fetch != nullptr);
     Q_ASSERT(uids.size() == 1);
     Q_ASSERT(messages.size() == 1);
 
