@@ -20,6 +20,7 @@
 */
 
 #include "sessionpool.h"
+#include "helper_p.h"
 
 #include <QtCore/QTimer>
 #include <QtNetwork/QSslSocket>
@@ -40,10 +41,10 @@ qint64 SessionPool::m_requestCounter = 0;
 SessionPool::SessionPool(int maxPoolSize, QObject *parent)
     : QObject(parent),
       m_maxPoolSize(maxPoolSize),
-      m_account(Q_NULLPTR),
-      m_passwordRequester(Q_NULLPTR),
+      m_account(nullptr),
+      m_passwordRequester(nullptr),
       m_initialConnectDone(false),
-      m_pendingInitialSession(Q_NULLPTR)
+      m_pendingInitialSession(nullptr)
 {
 }
 
@@ -118,11 +119,11 @@ void SessionPool::disconnect(SessionTermination termination)
     m_unusedPool.clear();
     m_reservedPool.clear();
     m_connectingPool.clear();
-    m_pendingInitialSession = Q_NULLPTR;
+    m_pendingInitialSession = nullptr;
     m_passwordRequester->cancelPasswordRequests();
 
     delete m_account;
-    m_account = Q_NULLPTR;
+    m_account = nullptr;
     m_namespaces.clear();
     m_capabilities.clear();
 
@@ -156,8 +157,8 @@ void SessionPool::cancelSessionRequest(qint64 id)
 
 void SessionPool::releaseSession(KIMAP::Session *session)
 {
-    if (m_reservedPool.contains(session)) {
-        m_reservedPool.removeAll(session);
+    const int removeSession = m_reservedPool.removeAll(session);
+    if (removeSession > 0) {
         m_unusedPool << session;
     }
 }
@@ -228,7 +229,7 @@ void SessionPool::declareSessionReady(KIMAP::Session *session)
         return;
     }
 
-    m_pendingInitialSession = Q_NULLPTR;
+    m_pendingInitialSession = nullptr;
 
     if (!m_initialConnectDone) {
         m_initialConnectDone = true;
@@ -252,7 +253,7 @@ void SessionPool::declareSessionReady(KIMAP::Session *session)
 void SessionPool::cancelSessionCreation(KIMAP::Session *session, int errorCode,
                                         const QString &errorMessage)
 {
-    m_pendingInitialSession = Q_NULLPTR;
+    m_pendingInitialSession = nullptr;
 
     QString msg;
     if (m_account) {
@@ -270,7 +271,7 @@ void SessionPool::cancelSessionCreation(KIMAP::Session *session, int errorCode,
             killSession(session, LogoutSession);
         }
         if (!m_pendingRequests.isEmpty()) {
-            Q_EMIT sessionRequestDone(m_pendingRequests.takeFirst(), Q_NULLPTR, errorCode, errorMessage);
+            Q_EMIT sessionRequestDone(m_pendingRequests.takeFirst(), nullptr, errorCode, errorMessage);
             if (!m_pendingRequests.isEmpty()) {
                 QTimer::singleShot(0, this, &SessionPool::processPendingRequests);
             }
@@ -300,7 +301,7 @@ void SessionPool::processPendingRequests()
         // No session available, and max pool size reached
         if (!m_pendingRequests.isEmpty()) {
             Q_EMIT sessionRequestDone(
-                m_pendingRequests.takeFirst(), Q_NULLPTR, NoAvailableSessionError,
+                m_pendingRequests.takeFirst(), nullptr, NoAvailableSessionError,
                 i18n("Could not create another extra connection to the IMAP-server %1.",
                      m_account->server()));
             if (!m_pendingRequests.isEmpty()) {
@@ -317,8 +318,8 @@ void SessionPool::onPasswordRequestDone(int resultType, const QString &password)
     if (!m_account) {
         // it looks like the connection was lost while we were waiting
         // for the password, we should fail all the pending requests and stop there
-        foreach (int request, m_pendingRequests) {
-            Q_EMIT sessionRequestDone(request, Q_NULLPTR,
+        for (int request : qAsConst(m_pendingRequests)) {
+            Q_EMIT sessionRequestDone(request, nullptr,
                                       LoginFailError, i18n("Disconnected from server during login."));
         }
         return;
@@ -358,7 +359,7 @@ void SessionPool::onPasswordRequestDone(int resultType, const QString &password)
         return;
     }
 
-    KIMAP::Session *session = Q_NULLPTR;
+    KIMAP::Session *session = nullptr;
     if (m_pendingInitialSession) {
         session = m_pendingInitialSession;
     } else {
@@ -451,11 +452,10 @@ void SessionPool::onCapabilitiesTestDone(KJob *job)
     }
 
     m_capabilities = capJob->capabilities();
-    QStringList expected;
-    expected << QStringLiteral("IMAP4REV1");
 
     QStringList missing;
-    foreach (const QString &capability, expected) {
+    const QStringList expected = {QStringLiteral("IMAP4REV1")};
+    for (const QString &capability : expected) {
         if (!m_capabilities.contains(capability)) {
             missing << capability;
         }
@@ -559,7 +559,7 @@ void SessionPool::onConnectionLost()
     if (m_unusedPool.isEmpty() && m_reservedPool.isEmpty()) {
         m_passwordRequester->cancelPasswordRequests();
         delete m_account;
-        m_account = Q_NULLPTR;
+        m_account = nullptr;
         m_namespaces.clear();
         m_capabilities.clear();
 
@@ -570,7 +570,7 @@ void SessionPool::onConnectionLost()
 
     session->deleteLater();
     if (session == m_pendingInitialSession) {
-        m_pendingInitialSession = Q_NULLPTR;
+        m_pendingInitialSession = nullptr;
     }
 }
 
