@@ -33,6 +33,7 @@
 #include "imapresource.h"
 #include "serverinfodialog.h"
 #include "folderarchivesettingpage.h"
+#include "utils.h"
 
 #include <mailtransport/transport.h>
 #include <mailtransport/servertest.h>
@@ -82,6 +83,8 @@ static QString authenticationModeString(MailTransport::Transport::EnumAuthentica
         return i18nc("Authentication method", "Clear text");
     case MailTransport::Transport::EnumAuthenticationType::ANONYMOUS:
         return i18nc("Authentication method", "Anonymous");
+    case MailTransport::Transport::EnumAuthenticationType::XOAUTH2:
+        return i18nc("Authentication method", "Gmail");
     default:
         break;
     }
@@ -116,7 +119,7 @@ static void addAuthenticationItem(QComboBox *authCombo, MailTransport::Transport
 }
 
 SetupServer::SetupServer(ImapResourceBase *parentResource, WId parent)
-    : QDialog(), m_parentResource(parentResource), m_ui(new Ui::SetupServerView), m_serverTest(Q_NULLPTR),
+    : QDialog(), m_parentResource(parentResource), m_ui(new Ui::SetupServerView), m_serverTest(nullptr),
       m_subscriptionsChanged(false), m_shouldClearCache(false), mValidator(this)
 {
     QNetworkConfigurationManager *networkConfigMgr = new QNetworkConfigurationManager(QCoreApplication::instance());
@@ -125,11 +128,11 @@ SetupServer::SetupServer(ImapResourceBase *parentResource, WId parent)
     QWidget *mainWidget = new QWidget(this);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(mainWidget);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     mOkButton->setDefault(true);
     mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
-    connect(buttonBox, &QDialogButtonBox::accepted, this, &SetupServer::accept);
+    connect(mOkButton, &QPushButton::clicked, this, &SetupServer::applySettings);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &SetupServer::reject);
     mainLayout->addWidget(buttonBox);
 
@@ -168,6 +171,7 @@ SetupServer::SetupServer(ImapResourceBase *parentResource, WId parent)
 
     connect(m_ui->testButton, &QPushButton::pressed, this, &SetupServer::slotTest);
 
+    connect(m_ui->imapServer, &KLineEdit::textChanged, this, &SetupServer::slotServerChanged);
     connect(m_ui->imapServer, &KLineEdit::textChanged, this, &SetupServer::slotTestChanged);
     connect(m_ui->imapServer, &KLineEdit::textChanged, this, &SetupServer::slotComplete);
     connect(m_ui->userName, &KLineEdit::textChanged, this, &SetupServer::slotComplete);
@@ -189,8 +193,6 @@ SetupServer::SetupServer(ImapResourceBase *parentResource, WId parent)
     slotCustomSieveChanged();
     connect(networkConfigMgr, &QNetworkConfigurationManager::onlineStateChanged,
             this, &SetupServer::slotTestChanged);
-
-    connect(mOkButton, &QPushButton::clicked, this, &SetupServer::applySettings);
 }
 
 SetupServer::~SetupServer()
@@ -250,6 +252,27 @@ void SetupServer::slotCustomSieveChanged()
 
 void SetupServer::applySettings()
 {
+    if (!m_parentResource->settings()->imapServer().isEmpty()
+        && m_ui->imapServer->text() != m_parentResource->settings()->imapServer()) {
+        if (KMessageBox::warningContinueCancel(
+                this, i18n("You have changed the address of the server. Even if this is the same server as before "
+                           "we will have to re-download all your emails from this account again. "
+                           "Are you sure you want to proceed?"),
+                i18n("Server address change")) == KMessageBox::Cancel) {
+            return;
+        }
+    }
+    if (!m_parentResource->settings()->userName().isEmpty()
+        && m_ui->userName->text() != m_parentResource->settings()->userName()) {
+        if (KMessageBox::warningContinueCancel(
+                this, i18n("You have changed the user name. Even if this is a user name for the same account as before "
+                           "we will have to re-download all your emails from this account again. "
+                           "Are you sure you want to proceed?"),
+                i18n("User name change")) == KMessageBox::Cancel) {
+            return;
+        }
+    }
+
     m_folderArchiveSettingPage->writeSettings();
     m_shouldClearCache = (m_parentResource->settings()->imapServer() != m_ui->imapServer->text())
                          || (m_parentResource->settings()->userName() != m_ui->userName->text());
@@ -333,6 +356,8 @@ void SetupServer::applySettings()
     if (m_oldResourceName != m_ui->accountName->text() && !m_ui->accountName->text().isEmpty()) {
         m_parentResource->settings()->renameRootCollection(m_ui->accountName->text());
     }
+
+    accept();
 }
 
 void SetupServer::readSettings()
@@ -381,7 +406,7 @@ void SetupServer::readSettings()
     const QString password = m_parentResource->settings()->password(&rejected);
     if (rejected) {
         m_ui->password->setEnabled(false);
-        KMessageBox::information(Q_NULLPTR, i18n("Could not access KWallet. "
+        KMessageBox::information(nullptr, i18n("Could not access KWallet. "
                                  "If you want to store the password permanently then you have to "
                                  "activate it. If you do not "
                                  "want to use KWallet, check the box below, but note that you will be "
@@ -433,12 +458,11 @@ void SetupServer::readSettings()
 
     m_ui->customUsername->setText(m_parentResource->settings()->sieveCustomUsername());
 
-
     rejected = false;
     const QString customPassword = m_parentResource->settings()->sieveCustomPassword(&rejected);
     if (rejected) {
         m_ui->customPassword->setEnabled(false);
-        KMessageBox::information(Q_NULLPTR, i18n("Could not access KWallet. "
+        KMessageBox::information(nullptr, i18n("Could not access KWallet. "
                                  "If you want to store the password permanently then you have to "
                                  "activate it. If you do not "
                                  "want to use KWallet, check the box below, but note that you will be "
@@ -495,7 +519,7 @@ void SetupServer::slotTest()
     m_serverTest->start();
 }
 
-void SetupServer::slotFinished(const QList<int> &testResult)
+void SetupServer::slotFinished(const QVector<int> &testResult)
 {
     qCDebug(IMAPRESOURCE_LOG) << testResult;
 
@@ -542,12 +566,13 @@ void SetupServer::slotFinished(const QList<int> &testResult)
 void SetupServer::slotTestChanged()
 {
     delete m_serverTest;
-    m_serverTest = Q_NULLPTR;
+    m_serverTest = nullptr;
     slotSafetyChanged();
 
     // do not use imapConnectionPossible, as the data is not yet saved.
-    m_ui->testButton->setEnabled(true /* TODO Global::connectionPossible() ||
-                                        m_ui->imapServer->text() == "localhost"*/);
+    const bool isGmail = Utils::isGmail(m_ui->imapServer->text());
+    m_ui->testButton->setEnabled(!isGmail /* TODO && Global::connectionPossible() ||
+                                                m_ui->imapServer->text() == "localhost"*/);
 }
 
 void SetupServer::slotEnableWidgets()
@@ -569,17 +594,18 @@ void SetupServer::slotComplete()
 
 void SetupServer::slotSafetyChanged()
 {
-    if (m_serverTest == Q_NULLPTR) {
+    if (m_serverTest == nullptr) {
+        const bool isGmail = Utils::isGmail(m_ui->imapServer->text());
         qCDebug(IMAPRESOURCE_LOG) << "serverTest null";
-        m_ui->noRadio->setEnabled(true);
-        m_ui->sslRadio->setEnabled(true);
-        m_ui->tlsRadio->setEnabled(true);
+        m_ui->noRadio->setEnabled(!isGmail);
+        m_ui->sslRadio->setEnabled(!isGmail);
+        m_ui->tlsRadio->setEnabled(!isGmail);
 
-        m_ui->authenticationCombo->setEnabled(true);
+        m_ui->authenticationCombo->setEnabled(!isGmail);
         return;
     }
 
-    QList<int> protocols;
+    QVector<int> protocols;
 
     switch (m_ui->safeImapGroup->checkedId()) {
     case KIMAP::LoginJob::Unencrypted :
@@ -678,4 +704,33 @@ void SetupServer::populateDefaultAuthenticationOptions(QComboBox *combo)
     addAuthenticationItem(combo, MailTransport::Transport::EnumAuthenticationType::NTLM);
     addAuthenticationItem(combo, MailTransport::Transport::EnumAuthenticationType::GSSAPI);
     addAuthenticationItem(combo, MailTransport::Transport::EnumAuthenticationType::ANONYMOUS);
+    if (Utils::isGmail(m_ui->imapServer->text())) {
+        addAuthenticationItem(combo, MailTransport::Transport::EnumAuthenticationType::XOAUTH2);
+    }
+}
+
+void SetupServer::slotServerChanged()
+{
+    const bool isGmail = Utils::isGmail(m_ui->imapServer->text());
+    const bool wasGmail = !m_ui->password->isEnabled();
+
+    if (isGmail == wasGmail) {
+        return;
+    }
+
+    m_ui->password->setEnabled(!isGmail);
+    m_ui->managesieveCheck->setChecked(m_ui->managesieveCheck->isChecked() && !isGmail);
+    m_ui->managesieveCheck->setEnabled(!isGmail);
+    m_ui->testButton->setEnabled(!isGmail);
+    m_ui->sslRadio->setChecked(m_ui->sslRadio->isChecked() || isGmail);
+    m_ui->noRadio->setEnabled(!isGmail);
+    m_ui->sslRadio->setEnabled(!isGmail);
+    m_ui->tlsRadio->setEnabled(!isGmail);
+    m_ui->portSpin->setValue(isGmail ? 993 : m_ui->portSpin->value());
+    m_ui->portSpin->setEnabled(!isGmail);
+    populateDefaultAuthenticationOptions(m_ui->authenticationCombo);
+    if (isGmail) {
+        setCurrentAuthMode(m_ui->authenticationCombo, MailTransport::Transport::EnumAuthenticationType::XOAUTH2);
+    }
+    m_ui->authenticationCombo->setEnabled(!isGmail);
 }
