@@ -50,16 +50,16 @@
 
 SubscriptionDialog::SubscriptionDialog(QWidget *parent, SubscriptionDialog::SubscriptionDialogOptions option)
     : QDialog(parent),
-      m_session(Q_NULLPTR),
+      m_session(nullptr),
       m_subscriptionChanged(false),
-      m_lineEdit(Q_NULLPTR),
+      m_lineEdit(nullptr),
       m_filter(new SubscriptionFilterProxyModel(this)),
       m_model(new QStandardItemModel(this))
 {
     QVBoxLayout *topLayout = new QVBoxLayout(this);
     setModal(true);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -200,7 +200,7 @@ void SubscriptionDialog::onReloadRequested()
     }
 
     KIMAP::ListJob *list = new KIMAP::ListJob(m_session);
-    list->setIncludeUnsubscribed(true);
+    list->setOption(KIMAP::ListJob::IncludeUnsubscribed);
     connect(list, &KIMAP::ListJob::mailBoxesReceived, this, &SubscriptionDialog::onMailBoxesReceived);
     connect(list, &KIMAP::ListJob::result, this, &SubscriptionDialog::onFullListingDone);
     list->start();
@@ -267,7 +267,7 @@ void SubscriptionDialog::onFullListingDone(KJob *job)
     }
 
     KIMAP::ListJob *list = new KIMAP::ListJob(m_session);
-    list->setIncludeUnsubscribed(false);
+    list->setOption(KIMAP::ListJob::NoOption);
     connect(list, &KIMAP::ListJob::mailBoxesReceived, this, &SubscriptionDialog::onSubscribedMailBoxesReceived);
     connect(list, &KIMAP::ListJob::result, this, &SubscriptionDialog::onReloadDone);
     list->start();
@@ -377,21 +377,3 @@ bool SubscriptionFilterProxyModel::acceptRow(int sourceRow, const QModelIndex &s
         return true;
     }
 }
-
-void SubscriptionDialog::onMobileLineEditChanged(const QString &text)
-{
-    if (!text.isEmpty() && !m_lineEdit->isVisible()) {
-        m_lineEdit->show();
-        m_lineEdit->setFocus();
-        m_lineEdit->grabKeyboard(); // Now the line edit runs the show
-    } else if (text.isEmpty() && m_lineEdit->isVisible()) {
-        m_lineEdit->hide();
-        grabKeyboard(); // Line edit gone, so let's get all the events for us again
-    }
-}
-
-void SubscriptionDialog::keyPressEvent(QKeyEvent *event)
-{
-    QDialog::keyPressEvent(event);
-}
-
