@@ -37,7 +37,7 @@ class UpdateMessageJob : public KJob
 {
     Q_OBJECT
 public:
-    UpdateMessageJob(const KMime::Message::Ptr &msg, KIMAP::Session *session, const QByteArray &kolabUid, const QSharedPointer<Merger> &merger, const QString &mailbox, qint64 uidNext = -1, qint64 oldUid = -1, QObject *parent = Q_NULLPTR);
+    UpdateMessageJob(const KMime::Message::Ptr &msg, KIMAP::Session *session, const QByteArray &kolabUid, const QSharedPointer<Merger> &merger, const QString &mailbox, qint64 uidNext = -1, qint64 oldUid = -1, QObject *parent = nullptr);
 
     qint64 newUid() const;
 
@@ -49,12 +49,12 @@ private:
     void appendMessage();
 
 private Q_SLOTS:
-    void onHeadersReceived(const QString&,
+    void onHeadersReceived(const QString &,
                            const QMap<qint64, qint64> &uids,
-                           const QMap<qint64, qint64>&,
-                           const QMap<qint64, KIMAP::MessageAttribute>&,
-                           const QMap<qint64, KIMAP::MessageFlags>&,
-                           const QMap<qint64, KIMAP::MessagePtr>&);
+                           const QMap<qint64, qint64> &,
+                           const QMap<qint64, KIMAP::MessageAttribute> &,
+                           const QMap<qint64, KIMAP::MessageFlags> &,
+                           const QMap<qint64, KIMAP::MessagePtr> &);
     void onHeadersFetchDone(KJob *job);
     void onSelectDone(KJob *job);
     void onSearchDone(KJob *job);
