@@ -327,7 +327,7 @@ void MaildirResource::itemChanged(const Akonadi::Item &item, const QSet<QByteArr
     bool bodyChanged = false;
     bool flagsChanged = false;
     bool headChanged = false;
-    Q_FOREACH (const QByteArray &part, parts)  {
+    for (const QByteArray &part : parts)  {
         if (part.startsWith("PLD:RFC822")) {
             bodyChanged = true;
         } else if (part.startsWith("PLD:HEAD")) {
@@ -485,7 +485,8 @@ Collection::List MaildirResource::listRecursive(const Collection &root, const Ma
 
     Collection::List list;
     const QStringList mimeTypes = QStringList() << itemMimeType() << Collection::mimeType();
-    foreach (const QString &sub, dir.subFolderList()) {
+    const QStringList lstDir = dir.subFolderList();
+    for (const QString &sub : lstDir) {
         Collection c;
         c.setName(sub);
         c.setRemoteId(sub);
@@ -582,7 +583,7 @@ void MaildirResource::collectionAdded(const Collection &collection, const Collec
         changeProcessed();
         return;
     } else {
-        const QString collectionName(collection.name().replace(QDir::separator(), QString()));
+        const QString collectionName(collection.name().remove(QDir::separator()));
         const QString newFolderPath = md.addSubFolder(collectionName);
         if (newFolderPath.isEmpty()) {
             changeProcessed();
@@ -628,7 +629,7 @@ void MaildirResource::collectionChanged(const Collection &collection)
         md.create();
     }
 
-    const QString collectionName(collection.name().replace(QDir::separator(), QString()));
+    const QString collectionName(collection.name().remove(QDir::separator()));
     if (!md.rename(collectionName)) {
         Q_EMIT error(i18n("Unable to rename maildir folder '%1'.", collection.name()));
         changeProcessed();
@@ -782,8 +783,7 @@ void MaildirResource::fsWatchDirFetchResult(KJob *job)
 void MaildirResource::slotFileChanged(const QFileInfo &fileInfo)
 {
     const QString key = fileInfo.fileName();
-    if (mChangedFiles.contains(key)) {
-        mChangedFiles.remove(key);
+    if (mChangedFiles.remove(key) > 0) {
         return;
     }
 
@@ -837,8 +837,8 @@ void MaildirResource::fsWatchFileFetchResult(KJob *job)
         item.setSize(entrySize);
     }
 
-    Item::Flags flags = md.readEntryFlags(fileName);
-    Q_FOREACH (const Item::Flag &flag, flags) {
+    const Item::Flags flags = md.readEntryFlags(fileName);
+    for (const Item::Flag &flag : flags) {
         item.setFlag(flag);
     }
 
