@@ -18,6 +18,7 @@
 */
 
 #include "deleteditemsattribute.h"
+#include "helper_p.h"
 
 DeletedItemsAttribute::DeletedItemsAttribute()
 {
@@ -65,10 +66,10 @@ KMBox::MBoxEntry::List DeletedItemsAttribute::deletedItemEntries() const
 
 void DeletedItemsAttribute::deserialize(const QByteArray &data)
 {
-    QList<QByteArray> offsets = data.split(',');
+    const QList<QByteArray> offsets = data.split(',');
     mDeletedItemOffsets.clear();
-
-    foreach (const QByteArray &offset, offsets) {
+    mDeletedItemOffsets.reserve(offsets.count());
+    for (const QByteArray &offset : offsets) {
         mDeletedItemOffsets.insert(offset.toULongLong());
     }
 }
@@ -77,9 +78,8 @@ QByteArray DeletedItemsAttribute::serialized() const
 {
     QByteArray serialized;
 
-    foreach (quint64 offset, mDeletedItemOffsets) {
-        serialized += QByteArray::number(offset);
-        serialized += ',';
+    for (quint64 offset : qAsConst(mDeletedItemOffsets)) {
+        serialized += QByteArray::number(offset) + ',';
     }
 
     serialized.chop(1);   // Remove the last ','
