@@ -34,7 +34,7 @@ class ObjectDeleteJob : public KJob
     Q_OBJECT
 
 public:
-    explicit ObjectDeleteJob(const Object &object, QObject *parent = Q_NULLPTR);
+    explicit ObjectDeleteJob(const Object &object, QObject *parent = nullptr);
 
     void start() Q_DECL_OVERRIDE;
 
