@@ -42,11 +42,11 @@ class AKONADI_FILESTORE_EXPORT ItemFetchJob : public Job
     Q_OBJECT
 
 public:
-    explicit ItemFetchJob(const Collection &collection, AbstractJobSession *session = Q_NULLPTR);
+    explicit ItemFetchJob(const Collection &collection, AbstractJobSession *session = nullptr);
 
-    explicit ItemFetchJob(const Item &item, AbstractJobSession *session = Q_NULLPTR);
+    explicit ItemFetchJob(const Item &item, AbstractJobSession *session = nullptr);
 
-    explicit ItemFetchJob(const Item::List &items, AbstractJobSession *session = Q_NULLPTR);
+    explicit ItemFetchJob(const Item::List &items, AbstractJobSession *session = nullptr);
 
     virtual ~ItemFetchJob();
 
