@@ -36,12 +36,12 @@
 #include <QtCore/QCryptographicHash>
 #include <QStandardPaths>
 
-Q_DECLARE_METATYPE(QEventLoopLocker*)
+Q_DECLARE_METATYPE(QEventLoopLocker *)
 
 using namespace Akonadi;
 
 SingleFileResourceBase::SingleFileResourceBase(const QString &id)
-    : ResourceBase(id), mDownloadJob(Q_NULLPTR), mUploadJob(Q_NULLPTR)
+    : ResourceBase(id), mDownloadJob(nullptr), mUploadJob(nullptr)
 {
     connect(this, &SingleFileResourceBase::reloadConfiguration, this, &SingleFileResourceBase::reloadFile);
     QTimer::singleShot(0, this, SLOT(readFile()));
@@ -268,8 +268,8 @@ void SingleFileResourceBase::slotDownloadJobResult(KJob *job)
         readLocalFile(QUrl::fromLocalFile(cacheFile()).toLocalFile());
     }
 
-    mDownloadJob = Q_NULLPTR;
-    auto ref = job->property("QEventLoopLocker").value<QEventLoopLocker*>();
+    mDownloadJob = nullptr;
+    auto ref = job->property("QEventLoopLocker").value<QEventLoopLocker *>();
     if (ref) {
         delete ref;
     }
@@ -285,8 +285,8 @@ void SingleFileResourceBase::slotUploadJobResult(KJob *job)
         Q_EMIT status(Broken, message);
     }
 
-    mUploadJob = Q_NULLPTR;
-    auto ref = job->property("QEventLoopLocker").value<QEventLoopLocker*>();
+    mUploadJob = nullptr;
+    auto ref = job->property("QEventLoopLocker").value<QEventLoopLocker *>();
     if (ref) {
         delete ref;
     }
